@@ -18,7 +18,7 @@ keep_empty <- function(fun) {
 #'
 #' @param x The character vector to style.
 #' @export
-#' @seealso [pillar-package] for a list of options
+#' @seealso [pillar_options] for a list of options
 #' @examples
 #' style_subtle("text")
 style_subtle <- keep_empty(function(x) {
@@ -116,7 +116,7 @@ num_colors <- local({
   num_colors <- NULL
   function(forget = FALSE) {
     if (is.null(num_colors) || forget) {
-      num_colors <<- crayon::num_colors(forget = forget)
+      num_colors <<- cli::num_ansi_colors()
     }
     num_colors
   }
