@@ -220,7 +220,20 @@ test_that("focus columns", {
 
   expect_snapshot(variant = variant, {
     tbl_format_setup(x, width = 30, focus = "b")
-    options(width = 15)
-    tbl_format_setup(x, width = 30, focus = "b")
+    tbl_format_setup(x, width = 20, focus = "b")
+    tbl_format_setup(x, width = 15, focus = "b")
+    tbl_format_setup(x, width = 10, focus = "b")
+    tbl_format_setup(x[2:1], width = 30, focus = "a")
+    tbl_format_setup(x[2:1], width = 20, focus = "a")
+    tbl_format_setup(x[2:1], width = 15, focus = "a")
+    tbl_format_setup(x[2:1], width = 10, focus = "a")
+    tbl_format_setup(x, width = 30, focus = c("a", "b"))
+    tbl_format_setup(x, width = 20, focus = c("a", "b"))
+    tbl_format_setup(x, width = 15, focus = c("a", "b"))
+    tbl_format_setup(x, width = 10, focus = c("a", "b"))
+    tbl_format_setup(x[2:1], width = 30, focus = c("a", "b"))
+    tbl_format_setup(x[2:1], width = 20, focus = c("a", "b"))
+    tbl_format_setup(x[2:1], width = 15, focus = c("a", "b"))
+    tbl_format_setup(x[2:1], width = 10, focus = c("a", "b"))
   })
 })
